summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTheo de Raadt <deraadt@cvs.openbsd.org>2006-05-25 03:38:35 +0000
committerTheo de Raadt <deraadt@cvs.openbsd.org>2006-05-25 03:38:35 +0000
commit2d681af2a5379297dedfe087968a3074de93396e (patch)
tree72483dced61c6041cb975c293ee25eb7bc3a4d02
parentedd57278096e25e1fc45ecd83d9e5b8f907a7f36 (diff)
also provide a seconds-of-progress counter; ok marco
-rw-r--r--sys/dev/biovar.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/sys/dev/biovar.h b/sys/dev/biovar.h
index 82708f740a0..91039e1e8bc 100644
--- a/sys/dev/biovar.h
+++ b/sys/dev/biovar.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: biovar.h,v 1.21 2006/05/25 03:11:59 deraadt Exp $ */
+/* $OpenBSD: biovar.h,v 1.22 2006/05/25 03:38:34 deraadt Exp $ */
/*
* Copyright (c) 2002 Niklas Hallqvist. All rights reserved.
@@ -102,7 +102,9 @@ struct bioc_vol {
void *bv_cookie;
int bv_volid; /* volume id */
- int bv_percent; /* percent done operation */
+ int16_t bv_percent; /* percent done operation */
+ u_int16_t bv_seconds; /* seconds of progress so far */
+
int bv_status; /* current status */
#define BIOC_SVONLINE 0x00
#define BIOC_SVONLINE_S "Online"